@@ -548,7 +548,7 @@ class Annotate(object):
         else:
             print('Your task has been completed!')
             print('You can get the result file type first through object.getResultType()')
-            print('You can download result file through data = object.getAnnoResult(result_type, %s)'%(task_id))
+            print('You can download result file through data = object.getAnnoResult(result_type, %s , cell_type)'%(task_id))
 
 
     
